@@ -25,7 +25,7 @@ class App:
             if not data.strip():
                 break
             handler_name, *args = data.strip().decode().split()
-            response = await self._get_response(handler_name, args)
+            response = await self._get_response(handler_name, [str(address).encode().decode(), *args])
             writer.write(response.encode())
             await writer.drain()
 
